package com.sample;

import java.io.InputStreamReader;
import java.io.Reader;

import org.drools.RuleBase;
import org.drools.RuleBaseFactory;
import org.drools.WorkingMemory;
import org.drools.compiler.PackageBuilder;
import org.drools.rule.Package;

public class DroolsTest {

    public static final void main(String[] args) {
        try {
        	
        	//Ucitavanje baze znanja
            RuleBase ruleBase = readRules();
            
            //Kreiranje radne memorije
            WorkingMemory workingMemory = ruleBase.newStatefulSession();
            
            //Kreiranje cinjenica
            Golfer g1 = new Golfer();
            g1.setIme("Fred");
            
            Golfer g2 = new Golfer();
            g2.setIme("Bob");
            
            Golfer g3 = new Golfer();
            g3.setIme("Tom");
            
            Golfer g4 = new Golfer();
            g4.setIme("Joe");
            
            //Ispisivanje cinjenica pre zakljucivanja
            System.out.println("Pocetno stanje cinjenica");
            System.out.println(g1);
            System.out.println(g2);
            System.out.println(g3);
            System.out.println(g4);

            //Unosenje cinjenica u radnu memoriju
            workingMemory.insert( g1 );
            workingMemory.insert( g2 );
            workingMemory.insert( g3 );
            workingMemory.insert( g4 );
            
            //Pokretanje ES
            workingMemory.fireAllRules();   
            
            //Ispisivanje rezultata
            System.out.println("Cinjenice posle zakljucivanja");
            System.out.println(g1);
            System.out.println(g2);
            System.out.println(g3);
            System.out.println(g4);

        } catch (Throwable t) {
            t.printStackTrace();
        }
    }

 	private static RuleBase readRules() throws Exception {
		//Ucitavanje pravila iz fajla
		Reader source = new InputStreamReader( DroolsTest.class.getResourceAsStream( "/Golf.drl" ) );
		
		//Kreiranje paketa koji sadrzi sva pravila
		PackageBuilder builder = new PackageBuilder();
		
		builder.addPackageFromDrl( source );
		
		Package pkg = builder.getPackage();
		
		//Kreiranje baze znanja i dodavanje paketa u nju
		RuleBase ruleBase = RuleBaseFactory.newRuleBase();
		ruleBase.addPackage( pkg );
		return ruleBase;
	}
	
}
